@@ -55,6 +55,8 @@ sub _open {
     my $sock;
 
     eval {
+        local $SIG{'ALRM'} = sub { die("connection timeout"); };
+        alarm($self->{'connect_timeout'});
         $sock = IO::Socket::INET->new(
                                          PeerAddr => $self->{'peer'},
                                          Type     => SOCK_STREAM,
@@ -67,6 +69,7 @@ sub _open {
             }
             $Monitoring::Livestatus::ErrorCode    = 500;
             $Monitoring::Livestatus::ErrorMessage = $msg;
+            alarm(0);
             return;
         }
 
@@ -78,6 +81,7 @@ sub _open {
         setsockopt($sock, IPPROTO_TCP, TCP_NODELAY, 1);
 
     };
+    alarm(0);
 
     if($@) {
         $Monitoring::Livestatus::ErrorCode    = 500;
